@@ -106,7 +106,6 @@ class ImageGenerator(
         img_batch,
         target_img_width: int = None,
         target_img_height: int = None,
-        crop_scaler: int = 1,
         num_crops=64,
         noise_factor: float = 0.11,
         pad_downscale: int = 3,
@@ -120,15 +119,14 @@ class ImageGenerator(
             target_img_width (int, optional): width of the augmented images. Defaults to img size.
             target_img_height (int, optional): height of the augmented images. Defaults to img size
             num_crops (int, optional): Number of augmentations to generate. Defaults to 32.
-            crop_scaler (int, optional): Scale range used when cropping. Defaults to 1.
 
         Returns:
             torch.Tensor: augmented batch of images.
         """
-        if target_img_height is None:
-            target_img_height = img_batch.shape[1]
         if target_img_width is None:
             target_img_width = img_batch.shape[2]
+        if target_img_height is None:
+            target_img_height = img_batch.shape[3]
 
         x_pad_size = target_img_width // pad_downscale
         y_pad_size = target_img_height // pad_downscale
@@ -174,16 +172,21 @@ class ImageGenerator(
                     crop_size),
                 (),
             )
-            augmented_img = aug_img_batch[:, :, offsety:offsety + crop_size,
-                                          offsetx:offsetx + crop_size, ]
+            augmented_img = aug_img_batch[:, :, offsetx:offsetx + crop_size,
+                                          offsety:offsety + crop_size, ]
 
             # else:
             #     augmented_img = aug_img_batch[:, :, x_pad_size:-x_pad_size,
             #                                   y_pad_size:-y_pad_size]
 
+            if target_img_height != target_img_width:
+                min_size = min(target_img_width, target_img_height)
+                augmented_img = torchvision.transforms.RandomCrop(
+                    (min_size, min_size))(augmented_img)
+
             augmented_img = torch.nn.functional.interpolate(
                 augmented_img,
-                (int(224 * crop_scaler), int(224 * crop_scaler)),
+                (self.clip_input_img_size, ) * 2,
                 mode='bilinear',
                 align_corners=True,
             )
