@@ -319,17 +319,17 @@ class TamingDecoder(ImageGenerator):
 
     def interpolate(
         self,
-        z_logits_list: List[torch.Tensor],
+        latents_list: List[torch.Tensor],
         duration_list: List[float],
         **kwargs,
     ) -> List[PIL.Image.Image]:
         """
         Returns a list of PIL images corresponding to the 
         generations produced by interpolating the values
-        from `z_logits_list`.
+        from `latents_list`.
 
         Args:
-            z_logits_list (List[torch.Tensor]): list of VQVAE 
+            latents_list (List[torch.Tensor]): list of VQVAE 
                 intermediate embeddings.
             duration_list (List[float]): list with the duration of
                 the interpolation between each consecutive tensor. 
@@ -339,6 +339,8 @@ class TamingDecoder(ImageGenerator):
         Returns:
             List[PIL.Image.Image]: list of the resulting generated images.
         """
+        z_logits_list = latents_list
+
         gen_img_list = []
         fps = 25
 
